@@ -1,9 +1,5 @@
 download_nc_basic <- function() {
-  if (Sys.info()["sysname"] == "Linux") {
-    tmpdir <- "/tmp"
-  } else{
-    tmpdir <- tempdir()
-  }
+  tmpdir <- tempdir()
 
   if (!file.exists(file.path(tmpdir, "nc_basic_spm_grass7.zip"))) {
     base_url <- "https://grass.osgeo.org/sampledata"
@@ -19,6 +15,7 @@ download_nc_basic <- function() {
       file.path(tmpdir, "nc_basic_spm_grass7.zip"),
       exdir = file.path(tmpdir, "grassdb")
     )
+    unlink(file.path(tmpdir, "nc_basic_spm_grass7.zip"))
   }
 
   dataset <- list(
